aboutsummaryrefslogtreecommitdiffstats
path: root/src/decoder/vorbis_decoder_plugin.c
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2012-09-04 13:05:12 +0200
committerMax Kellermann <max@duempel.org>2012-09-04 13:05:12 +0200
commitebf481e1a1d129f8ce9109ea97a77e5a55da128e (patch)
treef12d721c49cae61b92ab228df83a17d949a6fd1c /src/decoder/vorbis_decoder_plugin.c
parent5a52e9135087e1e28ef7f5a4e5282fec439fe866 (diff)
downloadmpd-ebf481e1a1d129f8ce9109ea97a77e5a55da128e.tar.gz
mpd-ebf481e1a1d129f8ce9109ea97a77e5a55da128e.tar.xz
mpd-ebf481e1a1d129f8ce9109ea97a77e5a55da128e.zip
decoder/ogg_common: rename to ogg_codec.c
Diffstat (limited to 'src/decoder/vorbis_decoder_plugin.c')
-rw-r--r--src/decoder/vorbis_decoder_plugin.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/decoder/vorbis_decoder_plugin.c b/src/decoder/vorbis_decoder_plugin.c
index e59f7a87f..09bb8c2a0 100644
--- a/src/decoder/vorbis_decoder_plugin.c
+++ b/src/decoder/vorbis_decoder_plugin.c
@@ -19,7 +19,7 @@
#include "config.h"
#include "vorbis_comments.h"
-#include "ogg_common.h"
+#include "ogg_codec.h"
#include "audio_check.h"
#include "uri.h"
#include "tag_handler.h"
@@ -184,10 +184,10 @@ vorbis_stream_decode(struct decoder *decoder,
const vorbis_info *vi;
enum decoder_command cmd = DECODE_COMMAND_NONE;
- if (ogg_stream_type_detect(decoder, input_stream) != VORBIS)
+ if (ogg_codec_detect(decoder, input_stream) != OGG_CODEC_VORBIS)
return;
/* rewind the stream, because ogg_stream_type_detect() has
moved it */
input_stream_lock_seek(input_stream, 0, SEEK_SET, NULL);
@@ -184,10 +184,10 @@ vorbis_stream_decode(struct decoder *decoder,
return;
- /* rewind the stream, because ogg_stream_type_detect() has
+ /* rewind the stream, because ogg_codec_detect() has
moved it */
input_stream_lock_seek(input_stream, 0, SEEK_SET, NULL);